def reg_equation(model):
    
    def term(coef, power):
        coef = coef if coef != 1 else ''
        power = (f'^{power}') if power > 1 else ''
        return f'{coef}x{power}'
    terms = []
    coefficients = model.coef_
    for power, coef in enumerate(coefficients, start=1):
        if coef != 0:
            terms.append(term(coef, power))
    return 'y = ' + ' + '.join(terms)



import numpy as np
import matplotlib.pyplot as plt
from matplotlib.colors import ListedColormap
cm2 = ListedColormap(['#0000aa', '#ff2020'])

def reg_plot(model,X,y):  
    line = np.linspace(X.min(), X.max(), 100).reshape(-1, 1)
    plt.figure(figsize=(8, 8))
    plt.plot(line, model.predict(line))
    plt.plot(X, y, 'o', c=cm2(0))
    ax = plt.gca()
    ax.legend(["Model", "Training data"], loc="best")
    ax.grid(True)
    plt.show()

